@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,29 @@ class SsaClient(AbstractClient):
     _service = 'ssa'
 
 
+    def DescribeAlarmStat(self, request):
+        """安全大屏-用户威胁告警信息
+
+        :param request: Request instance for DescribeAlarmStat.
+        :type request: :class:`tencentcloud.ssa.v20180608.models.DescribeAlarmStatRequest`
+        :rtype: :class:`tencentcloud.ssa.v20180608.models.DescribeAlarmStatResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAlarmStat", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAlarmStatResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAssetDetail(self, request):
         """资产安全页资产详情
 
@@ -46,7 +69,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAssetDetailList(self, request):
@@ -69,7 +92,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAssetList(self, request):
@@ -92,30 +115,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAssetsMappingList(self, request):
-        """资产测绘-测绘列表
-
-        :param request: Request instance for DescribeAssetsMappingList.
-        :type request: :class:`tencentcloud.ssa.v20180608.models.DescribeAssetsMappingListRequest`
-        :rtype: :class:`tencentcloud.ssa.v20180608.models.DescribeAssetsMappingListResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeAssetsMappingList", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeAssetsMappingListResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCheckConfigAssetList(self, request):
@@ -138,7 +138,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCheckConfigDetail(self, request):
@@ -161,7 +161,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeComplianceAssetList(self, request):
@@ -184,7 +184,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeComplianceDetail(self, request):
@@ -207,7 +207,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeComplianceList(self, request):
@@ -230,7 +230,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeConfigList(self, request):
@@ -253,11 +253,11 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDomainList(self, request):
-        """域名列表信息啊
+        """域名列表信息
 
         :param request: Request instance for DescribeDomainList.
         :type request: :class:`tencentcloud.ssa.v20180608.models.DescribeDomainListRequest`
@@ -276,7 +276,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeEventDetail(self, request):
@@ -299,7 +299,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeLeakDetectionList(self, request):
@@ -322,7 +322,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMappingResults(self, request):
@@ -345,30 +345,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeSafetyEventList(self, request):
-        """获取安全事件列表
-
-        :param request: Request instance for DescribeSafetyEventList.
-        :type request: :class:`tencentcloud.ssa.v20180608.models.DescribeSafetyEventListRequest`
-        :rtype: :class:`tencentcloud.ssa.v20180608.models.DescribeSafetyEventListResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeSafetyEventList", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeSafetyEventListResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSocAlertDetails(self, request):
@@ -391,7 +368,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSocAlertList(self, request):
@@ -414,7 +391,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSocCheckItemList(self, request):
@@ -437,7 +414,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSocCheckResultList(self, request):
@@ -460,7 +437,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSocCspmCompliance(self, request):
@@ -483,7 +460,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeVulDetail(self, request):
@@ -506,7 +483,7 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeVulList(self, request):
@@ -529,30 +506,30 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def SaDivulgeDataQueryPub(self, request):
-        """查询【通用字段】【泄露监测数据列表】
+    def SaDivulgeScanRuleMutate(self, request):
+        """SaDivulgeScanRuleMutate
 
-        :param request: Request instance for SaDivulgeDataQueryPub.
-        :type request: :class:`tencentcloud.ssa.v20180608.models.SaDivulgeDataQueryPubRequest`
-        :rtype: :class:`tencentcloud.ssa.v20180608.models.SaDivulgeDataQueryPubResponse`
+        :param request: Request instance for SaDivulgeScanRuleMutate.
+        :type request: :class:`tencentcloud.ssa.v20180608.models.SaDivulgeScanRuleMutateRequest`
+        :rtype: :class:`tencentcloud.ssa.v20180608.models.SaDivulgeScanRuleMutateResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("SaDivulgeDataQueryPub", params, headers=headers)
+            body = self.call("SaDivulgeScanRuleMutate", params, headers=headers)
             response = json.loads(body)
-            model = models.SaDivulgeDataQueryPubResponse()
+            model = models.SaDivulgeScanRuleMutateResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SaEventPub(self, request):
@@ -575,4 +552,4 @@ class SsaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
